==> plus-tree-selection-1.0.1.tgz: package/es/stores/department.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { departmentMap, employeeMap } from '../api';
import { post } from '../utils/httpClient';
var DepartmentStore = /*#__PURE__*/function () {
  function DepartmentStore() {
    _classCallCheck(this, DepartmentStore);
  }
  _createClass(DepartmentStore, [{
    key: "getSearchResultByname",
    value: function getSearchResultByname(name, env) {
      return post(employeeMap.get('SEARCH'), {
        name: name
      }, env);
    }
  }, {
    key: "getEmployeeOrdepartmentTree",
    value: function getEmployeeOrdepartmentTree(env) {
      return post(departmentMap.get('TREE'), {
        companyId: ''
      }, env);
    }
  }, {
    key: "getSearchEmployeeByNameAndPhoneAndEmial",
    value: function getSearchEmployeeByNameAndPhoneAndEmial(name, env) {
      return post(departmentMap.get('CONDITION'), {
        name: name
      }, env);
    }
  }]);
  return DepartmentStore;
}();
export default new DepartmentStore();

==> plus-tree-selection-1.0.4.tgz: package/es/stores/department.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import { departmentMap, employeeMap } from '../api';
import { post } from '../utils/httpClient';
var DepartmentStore = /*#__PURE__*/function () {
  function DepartmentStore() {
    _classCallCheck(this, DepartmentStore);
  }
  return _createClass(DepartmentStore, [{
    key: "getSearchResultByname",
    value: function getSearchResultByname(name, env) {
      return post(employeeMap.get('SEARCH'), {
        name: name
      }, env);
    }
  }, {
    key: "getEmployeeOrdepartmentTree",
    value: function getEmployeeOrdepartmentTree(env) {
      return post(departmentMap.get('TREE'), {
        companyId: ''
      }, env);
    }
  }, {
    key: "getSearchEmployeeByNameAndPhoneAndEmial",
    value: function getSearchEmployeeByNameAndPhoneAndEmial(name, env) {
      return post(departmentMap.get('CONDITION'), {
        name: name
      }, env);
    }
  }]);
}();
export default new DepartmentStore();
